Struct Bitmap

pub struct Bitmap {
    bytes: Vec<u8>,
    n_inputs: u32,
}
A Bitmap used to request proof elements in Utreexo proofs.

This bitmap represents which inputs the sender needs in the proof. Each bit in the bitmap corresponds to an input in the block, where true means the input should be included in the proof.

Fields

bytes: Vec<u8>

The actual bytes representing the bitmap.

n_inputs: u32

How many elements have been pushed into the bitmap.

Implementations

Source

impl Bitmap

pub fn new() -> Self

Creates a new empty Bitmap.

Use the push_input method to add inputs to the bitmap.

pub fn push_input(&mut self, request: bool)

Adds a new input to the bitmap. This method takes a boolean request which indicates whether the input should be requested from our remote peer.

pub fn is_empty(&self) -> bool

Returns whether the bitmap is empty (i.e., has no inputs).