pub struct GetUtreexoProof {
pub block_hash: BlockHash,
pub request_bitmap: UtreexoProofMask,
pub proof_hashes_bitmap: Bitmap,
pub leaf_index_bitmap: Bitmap,
}Expand description
Represents a Utreexo proof request, for a specific block.
Fields
block_hash: BlockHashThe block hash for which the proof is requested.
request_bitmap: UtreexoProofMaskWhich parts of the proof data do we want
proof_hashes_bitmap: BitmapA bitmap indicating which proof hashes to include in the response.
leaf_index_bitmap: BitmapA bitmap indicating which leaf indices to include in the response.