pub struct UtreexoProof {
pub block_hash: BlockHash,
pub proof_hashes: Vec<BitcoinNodeHash>,
pub targets: Vec<u64>,
pub leaf_data: Vec<CompactLeafData>,
}Expand description
Represents a Utreexo proof for a specific block.
This message will be sent in response to a GetUtreexoProof request.
Fields
block_hash: BlockHashThe block hash for which the proof is provided.
proof_hashes: Vec<BitcoinNodeHash>The proof hashes for the requested inputs.
targets: Vec<u64>The targets for the requested inputs.
Targets are numerical values representing the positions of the UTXOs being spent inside the forest. Using the target positions and hashes, we can recompute the forest roots, and verify whether the proof is valid.
leaf_data: Vec<CompactLeafData>The leaf data for the requested inputs.